@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Base;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 # ABSTRACT: Base module for importing standard modules, features, and subs
 
 #pod =head1 SYNOPSIS
@@ -38,7 +38,7 @@ use base 'Import::Base';
 
 our @IMPORT_MODULES = (
     'strict', 'warnings',
-    feature => [qw( signatures )],
+    feature => [qw( :5.24 signatures )],
     '-warnings' => [qw( experimental::signatures )],
 );
 
@@ -61,7 +61,7 @@ CPAN::Testers::Schema::Base - Base module for importing standard modules, featur
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
