@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::Result::Release;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 # ABSTRACT: Collected test report stats about a single CPAN release
 
 #pod =head1 SYNOPSIS
@@ -235,6 +235,22 @@ __PACKAGE__->belongs_to(
     upload => 'CPAN::Testers::Schema::Result::Upload' => 'uploadid',
 );
 
+#pod =method report
+#pod
+#pod Get the related row from the `cpanstats` table. See
+#pod L<CPAN::Testers::Schema::Result::Stats>.
+#pod
+#pod This report is the latest report, by date, that went in to this release
+#pod summary. The date field in the report can be used to determine when this
+#pod release was last updated.
+#pod
+#pod =cut
+
+__PACKAGE__->belongs_to(
+    report => 'CPAN::Testers::Schema::Result::Stats',
+    { 'foreign.guid' => 'self.guid' },
+);
+
 1;
 
 __END__
@@ -247,7 +263,7 @@ CPAN::Testers::Schema::Result::Release - Collected test report stats about a sin
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -336,6 +352,15 @@ The ID of this upload from the `uploads` table.
 Get the related row from the `uploads` table. See
 L<CPAN::Testers::Schema::Result::Upload>.
 
+=head2 report
+
+Get the related row from the `cpanstats` table. See
+L<CPAN::Testers::Schema::Result::Stats>.
+
+This report is the latest report, by date, that went in to this release
+summary. The date field in the report can be used to determine when this
+release was last updated.
+
 =head1 SEE ALSO
 
 =over 4
